@@ -10,12 +10,6 @@ See the README file for information on usage and installation.
 See the LICENSE file for information on distribution.
 
 """
-import astCalc
-import astCoords
-import astImages
-import astPlots
-import astStats
-import astWCS
-import astSED
 
-__version__ = '0.6.0'
+__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS', 'astSED']
+__version__ = '0.6.1'
