@@ -1040,7 +1040,7 @@ class P09Model(StellarPopulation):
         self.fluxGrid=self.fluxGrid/4.3607e-33/1e10
         
 #------------------------------------------------------------------------------------------------------------
-def makeModelSEDDictList(modelList, z, passbandsList, EBMinusVList = [0.0], forceYoungerThanUniverse = True):
+def makeModelSEDDictList(modelList, z, passbandsList, labelsList = [], EBMinusVList = [0.0], forceYoungerThanUniverse = True):
     """This routine makes a list of SEDDict dictionaries (see L{mags2SEDDict}) for fitting using 
     L{fitSEDDict}. This speeds up the fitting as this allows us to calculate model SED magnitudes only once, 
     if all objects to be fitted are at the same redshift. We add some meta data to the modelSEDDicts (e.g.
@@ -1058,6 +1058,8 @@ def makeModelSEDDictList(modelList, z, passbandsList, EBMinusVList = [0.0], forc
     @param z: redshift to apply to all stellar population models in modelList
     @type EBMinusVList: list
     @param EBMinusVList: list of E(B-V) extinction values to apply to all models, in magnitudes
+    @type labelsList: list
+    @param labelsList: optional list used for labelling passbands in output SEDDicts
     @type forceYoungerThanUniverse: bool
     @param forceYoungerThanUniverse: if True, do not allow models that exceed the age of the universe at z
     @rtype: list
@@ -1082,6 +1084,7 @@ def makeModelSEDDictList(modelList, z, passbandsList, EBMinusVList = [0.0], forc
                 except:
                     raise Exception, "Model %s has a wavelength range that doesn't cover ~1200-22000 Angstroms" % (modelList[m].fileName)
                 modelSEDDict=s.getSEDDict(passbandsList)
+                modelSEDDict['labels']=labelsList
                 modelSEDDict['E(B-V)']=EBMinusV
                 modelSEDDict['ageGyr']=t
                 modelSEDDict['z']=z
