@@ -13,8 +13,8 @@ img=pyfits.open(TEST_IMAGE)
 wcs=astWCS.WCS(TEST_IMAGE)
 d=img[0].data
 
-f=astPlots.ImagePlot(d, wcs, axes=[0,0,1,1])
-f.addCompass("SW", 20.0)
+f=astPlots.ImagePlot(d, wcs, axes = [0, 0, 1, 1])
+f.addCompass("SE", 60.0, color = 'red')
 
 f.draw()
 f.save("output_compassTest.png")
